seqtools.partition_sequence_by_restricted_growth_function
=========================================================

.. autofunction:: abjad.tools.seqtools.partition_sequence_by_restricted_growth_function
